==> zio-aws-timestreamwrite_2.13-5.17.104.12-sources.jar: zio/aws/timestreamwrite/model/MagneticStoreRejectedDataLocation.scala <==
package zio.aws.timestreamwrite.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class MagneticStoreRejectedDataLocation(
    s3Configuration: Option[zio.aws.timestreamwrite.model.S3Configuration] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.timestreamwrite.model.MagneticStoreRejectedDataLocation = {
    import MagneticStoreRejectedDataLocation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.timestreamwrite.model.MagneticStoreRejectedDataLocation
      .builder()
      .optionallyWith(s3Configuration.map(value => value.buildAwsValue()))(
        _.s3Configuration
      )
      .build()
  }
  def asReadOnly
      : zio.aws.timestreamwrite.model.MagneticStoreRejectedDataLocation.ReadOnly =
    zio.aws.timestreamwrite.model.MagneticStoreRejectedDataLocation
      .wrap(buildAwsValue())
}
object MagneticStoreRejectedDataLocation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.timestreamwrite.model.MagneticStoreRejectedDataLocation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.timestreamwrite.model.MagneticStoreRejectedDataLocation =
      zio.aws.timestreamwrite.model.MagneticStoreRejectedDataLocation(
        s3Configuration.map(value => value.asEditable)
      )
    def s3Configuration
        : Option[zio.aws.timestreamwrite.model.S3Configuration.ReadOnly]
    def getS3Configuration: ZIO[
      Any,
      AwsError,
      zio.aws.timestreamwrite.model.S3Configuration.ReadOnly
    ] = AwsError.unwrapOptionField("s3Configuration", s3Configuration)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.timestreamwrite.model.MagneticStoreRejectedDataLocation
  ) extends zio.aws.timestreamwrite.model.MagneticStoreRejectedDataLocation.ReadOnly {
    override val s3Configuration
        : Option[zio.aws.timestreamwrite.model.S3Configuration.ReadOnly] = scala
      .Option(impl.s3Configuration())
      .map(value => zio.aws.timestreamwrite.model.S3Configuration.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.timestreamwrite.model.MagneticStoreRejectedDataLocation
  ): zio.aws.timestreamwrite.model.MagneticStoreRejectedDataLocation.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-timestreamwrite_2.13-6.20.47.1-sources.jar: zio/aws/timestreamwrite/model/MagneticStoreRejectedDataLocation.scala <==
package zio.aws.timestreamwrite.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class MagneticStoreRejectedDataLocation(
    s3Configuration: Optional[zio.aws.timestreamwrite.model.S3Configuration] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.timestreamwrite.model.MagneticStoreRejectedDataLocation = {
    import MagneticStoreRejectedDataLocation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.timestreamwrite.model.MagneticStoreRejectedDataLocation
      .builder()
      .optionallyWith(s3Configuration.map(value => value.buildAwsValue()))(
        _.s3Configuration
      )
      .build()
  }
  def asReadOnly
      : zio.aws.timestreamwrite.model.MagneticStoreRejectedDataLocation.ReadOnly =
    zio.aws.timestreamwrite.model.MagneticStoreRejectedDataLocation
      .wrap(buildAwsValue())
}
object MagneticStoreRejectedDataLocation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.timestreamwrite.model.MagneticStoreRejectedDataLocation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.timestreamwrite.model.MagneticStoreRejectedDataLocation =
      zio.aws.timestreamwrite.model.MagneticStoreRejectedDataLocation(
        s3Configuration.map(value => value.asEditable)
      )
    def s3Configuration
        : Optional[zio.aws.timestreamwrite.model.S3Configuration.ReadOnly]
    def getS3Configuration: ZIO[
      Any,
      AwsError,
      zio.aws.timestreamwrite.model.S3Configuration.ReadOnly
    ] = AwsError.unwrapOptionField("s3Configuration", s3Configuration)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.timestreamwrite.model.MagneticStoreRejectedDataLocation
  ) extends zio.aws.timestreamwrite.model.MagneticStoreRejectedDataLocation.ReadOnly {
    override val s3Configuration
        : Optional[zio.aws.timestreamwrite.model.S3Configuration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.s3Configuration())
        .map(value => zio.aws.timestreamwrite.model.S3Configuration.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.timestreamwrite.model.MagneticStoreRejectedDataLocation
  ): zio.aws.timestreamwrite.model.MagneticStoreRejectedDataLocation.ReadOnly =
    new Wrapper(impl)
}
